@@ -1,10 +1,7 @@
 from __future__ import print_function
 
 import argparse
-import logging
-import sys
 import os.path
-from glob import glob
 
 import ssg.build_profile
 import ssg.build_yaml
@@ -13,6 +10,7 @@ import ssg.controls
 import ssg.products
 import ssg.environment
 from ssg.build_cpe import ProductCPEs
+from ssg.constants import BENCHMARKS
 
 def create_parser():
     parser = argparse.ArgumentParser()
@@ -32,9 +30,9 @@ def create_parser():
         "--resolved-base", required=True,
         help="To which directory to put processed rule/group/value YAMLs.")
     parser.add_argument(
-        "--controls-dir",
-        help="Directory that contains control files with policy controls. "
-        "e.g.: ~/scap-security-guide/controls",
+        "--project-root",
+        help="Path to the repository ie. project root "
+        "e.g.: ~/scap-security-guide/",
     )
     parser.add_argument(
         "--sce-metadata",
@@ -85,14 +83,11 @@ def dump_compiled_profile(base_dir, profile):
     profile.dump_yaml(dest)
 
 
-def get_all_resolved_profiles_by_id(env_yaml, product_yaml, loader, product_cpes, controls_dir=None):
-    controls_manager = None
-    if controls_dir:
-        controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-        controls_manager.load()
-
+def get_all_resolved_profiles_by_id(
+        env_yaml, product_yaml, loader, product_cpes, controls_manager, controls_dir=None):
     profile_files = ssg.products.get_profile_files_from_root(env_yaml, product_yaml)
-    profiles_by_id = load_resolve_and_validate_profiles(env_yaml, profile_files, loader, controls_manager, product_cpes)
+    profiles_by_id = load_resolve_and_validate_profiles(
+        env_yaml, profile_files, loader, controls_manager, product_cpes)
     return profiles_by_id
 
 
@@ -108,12 +103,24 @@ def load_resolve_and_validate_profiles(env_yaml, profile_files, loader, controls
     return profiles_by_id
 
 
-def save_everything(base_dir, loader, profiles):
+def save_everything(base_dir, loader, controls_manager, profiles):
+    controls_manager.save_everything(os.path.join(base_dir, "controls"))
     loader.save_all_entities(base_dir)
     for p in profiles:
         dump_compiled_profile(base_dir, p)
 
 
+def find_existing_rules(project_root):
+    rules = set()
+    for benchmark in BENCHMARKS:
+        benchmark = os.path.join(project_root, benchmark)
+        for dirpath, _, filenames in os.walk(benchmark):
+            if "rule.yml" in filenames:
+                rule_id = os.path.basename(dirpath)
+                rules.add(rule_id)
+    return rules
+
+
 def main():
     parser = create_parser()
     args = parser.parse_args()
@@ -124,20 +131,26 @@ def main():
     product_cpes.load_product_cpes(env_yaml)
     product_cpes.load_content_cpes(env_yaml)
 
-    build_root = os.path.dirname(args.build_config_yaml)
-
-    logfile = "{build_root}/{product}/control_profiles.log".format(
-            build_root=build_root,
-            product=env_yaml["product"])
-    logging.basicConfig(filename=logfile, level=logging.INFO)
-
     loader = ssg.build_yaml.BuildLoader(
         None, env_yaml, product_cpes, args.sce_metadata, args.stig_references)
+    loader.load_components()
     load_benchmark_source_data_from_directory_tree(loader, env_yaml, product_yaml)
 
-    profiles_by_id = get_all_resolved_profiles_by_id(env_yaml, product_yaml, loader, product_cpes, args.controls_dir)
+    project_root_abspath = os.path.abspath(args.project_root)
+    controls_dir = os.path.join(project_root_abspath, "controls")
 
-    save_everything(args.resolved_base, loader, profiles_by_id.values())
+    existing_rules = find_existing_rules(project_root_abspath)
+
+    controls_manager = ssg.controls.ControlsManager(
+        controls_dir, env_yaml, existing_rules)
+    controls_manager.load()
+    controls_manager.remove_selections_not_known(loader.all_rules)
+
+    profiles_by_id = get_all_resolved_profiles_by_id(
+        env_yaml, product_yaml, loader, product_cpes, controls_manager, controls_dir)
+
+    save_everything(
+        args.resolved_base, loader, controls_manager, profiles_by_id.values())
 
 
 if __name__ == "__main__":
