@@ -11,6 +11,10 @@ def create_parser():
         "e.g.: ~/scap-security-guide/products/rhel7/product.yml "
         "needed for autodetection of profile root"
     )
+    parser.add_argument(
+        "--product-properties",
+        help="The directory with additional product properties yamls."
+    )
     parser.add_argument(
         "--compiled-product-yaml", required=True,
         help="Where to save the compiled product yaml."
@@ -23,6 +27,8 @@ def main():
     args = parser.parse_args()
 
     product = ssg.products.Product(args.product_yaml)
+    if args.product_properties:
+        product.read_properties_from_directory(args.product_properties)
     product.write(args.compiled_product_yaml)
 
 
