@@ -3,7 +3,7 @@
 #
 # profiles = xccdf_org.ssgproject.content_profile_stig
 
-yum remove -y ntp
+{{{ bash_package_remove("ntp") }}}
 
 # Remove all pool options
 sed -i "/^pool.*/d" {{{ chrony_conf_path }}}
