@@ -8,7 +8,11 @@ test root:{{{ groupname }}} = "$(stat -c "%U:%G" "$keyfile")"
 for keyfile in /etc/ssh/*_key; do
     test -f "$keyfile" || continue
     if {{{ keyfile_owned_by("root") }}}; then
+    {{% if product in ["sle12", "sle15"] %}}
+	chmod u-xs,g-xws,o-xwrt "$keyfile"
+    {{% else %}}
 	chmod u-xs,g-xwrs,o-xwrt "$keyfile"
+    {{% endif %}}
     {{% if dedicated_ssh_groupname -%}}
     elif {{{ keyfile_owned_by(dedicated_ssh_groupname) }}}; then
 	chmod u-xs,g-xws,o-xwrt "$keyfile"
