@@ -1,4 +1,4 @@
 #!/bin/bash
 # platform = multi_platform_fedora,Oracle Linux 8,Oracle Linux 9,Red Hat Enterprise Linux 8,Red Hat Enterprise Linux 9
 
-yum remove -y bind || true
+{{{ bash_package_remove("bind") }}}
