@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# platform = multi_platform_fedora,Red Hat Enterprise Linux 9
+# platform = multi_platform_fedora,Oracle Linux 8,Oracle Linux 9,Red Hat Enterprise Linux 9
 
 SSHD_PARAM={{{ PARAMETER }}}
 SSHD_VAL="bad_val"
@@ -8,6 +8,10 @@ SSHD_VAL="bad_val"
 mkdir -p /etc/ssh/sshd_config.d
 touch /etc/ssh/sshd_config.d/nothing
 
+{{% if product in ["ol8", "ol9"] %}}
+{{{ bash_replace_or_append("/etc/ssh/sshd_config", "Include", "/etc/ssh/sshd_config.d/*.conf", "%s %s") }}}
+{{% endif %}}
+
 if grep -q "^\s*${SSHD_PARAM}" /etc/ssh/sshd_config /etc/ssh/sshd_config.d/* ; then
 	sed -i "/^\s*${SSHD_PARAM}.*/Id" /etc/ssh/sshd_config /etc/ssh/sshd_config.d/*
 fi
