@@ -12,6 +12,7 @@ import glob
 
 
 import ssg.build_remediations
+import ssg.components
 from .build_cpe import CPEALLogicalTest, CPEALCheckFactRef, ProductCPEs
 from .constants import (XCCDF12_NS,
                         OSCAP_BENCHMARK,
@@ -30,6 +31,7 @@ from .constants import (XCCDF12_NS,
                         SSG_BENCHMARK_LATEST_URI,
                         SSG_PROJECT_NAME,
                         SSG_REF_URIS,
+                        SSG_IDENT_URIS,
                         PREFIX_TO_NS,
                         FIX_TYPE_TO_SYSTEM
                         )
@@ -111,13 +113,13 @@ def add_reference_elements(element, references, ref_uri_dict):
                 else:
                     raise ValueError("SRG {0} doesn't have a URI defined.".format(ref_val))
             else:
-                try:
-                    ref_href = ref_uri_dict[ref_type]
-                except KeyError as exc:
+                if ref_type not in ref_uri_dict.keys():
                     msg = (
-                        "Error processing reference {0}: {1} in Rule {2}."
-                        .format(ref_type, ref_vals, self.id_))
+                        "Error processing reference {0}: {1}. A reference type "
+                        "has been added that the project doesn't know about."
+                        .format(ref_type, ref_vals))
                     raise ValueError(msg)
+                ref_href = ref_uri_dict[ref_type]
 
             ref = ET.SubElement(element, '{%s}reference' % XCCDF12_NS)
             ref.set("href", ref_href)
@@ -657,6 +659,7 @@ class Rule(XCCDFEntity, Templatable):
         rationale=lambda: "",
         severity=lambda: "",
         references=lambda: dict(),
+        components=lambda: list(),
         identifiers=lambda: dict(),
         ocil_clause=lambda: None,
         ocil=lambda: None,
@@ -754,13 +757,6 @@ class Rule(XCCDFEntity, Templatable):
         rule.validate_references(yaml_file)
         return rule
 
-    def _verify_stigid_format(self, product):
-        stig_id = self.references.get("stigid", None)
-        if not stig_id:
-            return
-        if "," in stig_id:
-            raise ValueError("Rules can not have multiple STIG IDs.")
-
     def _verify_disa_cci_format(self):
         cci_id = self.references.get("disa", None)
         if not cci_id:
@@ -788,10 +784,16 @@ class Rule(XCCDFEntity, Templatable):
         stig_id = self.references.get("stigid", None)
         if not stig_id:
             return
-        reference = stig_references.get(stig_id, None)
-        if not reference:
-            return
-        self.references["stigref"] = reference
+
+        references = []
+        for id in stig_id.split(","):
+            reference = stig_references.get(id, None)
+            if not reference:
+                continue
+            references.append(reference)
+
+        if references:
+            self.references["stigref"] = ",".join(references)
 
     def _get_product_only_references(self):
         product_references = dict()
@@ -892,8 +894,6 @@ class Rule(XCCDFEntity, Templatable):
         self._verify_disa_cci_format()
         self.references.update(product_references)
 
-        self._verify_stigid_format(product)
-
     def validate_identifiers(self, yaml_file):
         if self.identifiers is None:
             raise ValueError("Empty identifier section in file %s" % yaml_file)
@@ -961,6 +961,15 @@ class Rule(XCCDFEntity, Templatable):
             # into corresponding XCCDF <sub> elements
             ssg.build_remediations.expand_xccdf_subs(fix_el, fix_type)
 
+    def _add_ident_elements(self, rule):
+        for ident_type, ident_val in self.identifiers.items():
+            if ident_type not in SSG_IDENT_URIS:
+                msg = "Invalid identifier type '%s' in rule '%s'" % (ident_type, self.id_)
+                raise ValueError(msg)
+            ident = ET.SubElement(rule, '{%s}ident' % XCCDF12_NS)
+            ident.set("system", SSG_IDENT_URIS[ident_type])
+            ident.text = ident_val
+
     def to_xml_element(self, env_yaml=None):
         rule = ET.Element('{%s}Rule' % XCCDF12_NS)
         rule.set('selected', 'false')
@@ -989,11 +998,7 @@ class Rule(XCCDFEntity, Templatable):
             rule, "conflicts", "idref",
             list(map(lambda x: OSCAP_RULE + x, self.conflicts)))
 
-        for ident_type, ident_val in self.identifiers.items():
-            ident = ET.SubElement(rule, '{%s}ident' % XCCDF12_NS)
-            if ident_type == 'cce':
-                ident.set('system', cce_uri)
-                ident.text = ident_val
+        self._add_ident_elements(rule)
         self._add_fixes_elements(rule)
 
         ocil_parent = rule
@@ -1331,6 +1336,19 @@ class BuildLoader(DirectoryLoader):
         self.stig_references = None
         if stig_reference_path:
             self.stig_references = ssg.build_stig.map_versions_to_rule_ids(stig_reference_path)
+        self.components_dir = None
+        self.rule_to_components = None
+
+    def load_components(self):
+        if "components_root" not in self.env_yaml:
+            return None
+        product_dir = self.env_yaml["product_dir"]
+        components_root = self.env_yaml["components_root"]
+        self.components_dir = os.path.abspath(
+            os.path.join(product_dir, components_root))
+        components = ssg.components.load(self.components_dir)
+        self.rule_to_components = ssg.components.rule_component_mapping(
+            components)
 
     def _process_values(self):
         for value_yaml in self.value_files:
@@ -1338,6 +1356,25 @@ class BuildLoader(DirectoryLoader):
             self.all_values[value.id_] = value
             self.loaded_group.add_value(value)
 
+    def _process_rule(self, rule):
+        if self.rule_to_components is not None and rule.id_ not in self.rule_to_components:
+            raise ValueError(
+                "The rule '%s' isn't mapped to any component! Insert the "
+                "rule ID to at least one file in '%s'." %
+                (rule.id_, self.components_dir))
+        prodtypes = parse_prodtype(rule.prodtype)
+        if "all" not in prodtypes and self.product not in prodtypes:
+            return False
+        self.all_rules[rule.id_] = rule
+        self.loaded_group.add_rule(
+            rule, env_yaml=self.env_yaml, product_cpes=self.product_cpes)
+        rule.normalize(self.env_yaml["product"])
+        if self.stig_references:
+            rule.add_stig_references(self.stig_references)
+        if self.rule_to_components is not None:
+            rule.components = self.rule_to_components[rule.id_]
+        return True
+
     def _process_rules(self):
         for rule_yaml in self.rule_files:
             try:
@@ -1346,16 +1383,8 @@ class BuildLoader(DirectoryLoader):
             except DocumentationNotComplete:
                 # Happens on non-debug build when a rule is "documentation-incomplete"
                 continue
-            prodtypes = parse_prodtype(rule.prodtype)
-            if "all" not in prodtypes and self.product not in prodtypes:
+            if not self._process_rule(rule):
                 continue
-            self.all_rules[rule.id_] = rule
-            self.loaded_group.add_rule(
-                rule, env_yaml=self.env_yaml, product_cpes=self.product_cpes)
-
-            rule.normalize(self.env_yaml["product"])
-            if self.stig_references:
-                rule.add_stig_references(self.stig_references)
 
     def _get_new_loader(self):
         loader = BuildLoader(
@@ -1364,6 +1393,8 @@ class BuildLoader(DirectoryLoader):
         loader.sce_metadata = self.sce_metadata
         # Do it this way so we only have to parse the STIG references once.
         loader.stig_references = self.stig_references
+        # Do it this way so we only have to parse the component metadata once.
+        loader.rule_to_components = self.rule_to_components
         return loader
 
     def export_group_to_file(self, filename):
