@@ -28,7 +28,7 @@ SSG_REF_URIS = {
     'ospp': 'https://www.niap-ccevs.org/Profile/PP.cfm',
     'hipaa': 'https://www.gpo.gov/fdsys/pkg/CFR-2007-title45-vol1/pdf/CFR-2007-title45-vol1-chapA-subchapC.pdf',
     'ism': 'https://www.cyber.gov.au/acsc/view-all-content/ism',
-    'iso27001-2013': 'https://www.iso.org/standard/54534.html',
+    'iso27001-2013': 'https://www.iso.org/contents/data/standard/05/45/54534.html',
     'nerc-cip': 'https://www.nerc.com/pa/Stand/Standard%20Purpose%20Statement%20DL/US_Standard_One-Stop-Shop.xlsx',
     'stigid': 'https://public.cyber.mil/stigs/downloads/?_dl_facet_stigs=operating-systems%2Cunix-linux',
     'os-srg': 'https://public.cyber.mil/stigs/downloads/?_dl_facet_stigs=operating-systems%2Cgeneral-purpose-os',
@@ -40,8 +40,9 @@ product_directories = [
     'alinux2',
     'alinux3',
     'anolis8',
+    'anolis23',
     'chromium',
-    'debian10', 'debian11',
+    'debian10', 'debian11', 'debian12',
     'example',
     'eks',
     'fedora',
@@ -51,6 +52,7 @@ product_directories = [
     'rhcos4',
     'ol7', 'ol8', 'ol9',
     'opensuse',
+    'openembedded',
     'rhel7', 'rhel8', 'rhel9',
     'rhv4',
     'sle12', 'sle15',
@@ -194,9 +196,11 @@ FULL_NAME_TO_PRODUCT_MAPPING = {
     "Alibaba Cloud Linux 2": "alinux2",
     "Alibaba Cloud Linux 3": "alinux3",
     "Anolis OS 8": "anolis8",
+    "Anolis OS 23": "anolis23",
     "Chromium": "chromium",
     "Debian 10": "debian10",
     "Debian 11": "debian11",
+    "Debian 12": "debian12",
     "Example": "example",
     "Amazon Elastic Kubernetes Service": "eks",
     "Fedora": "fedora",
@@ -219,6 +223,7 @@ FULL_NAME_TO_PRODUCT_MAPPING = {
     "Ubuntu 20.04": "ubuntu2004",
     "Ubuntu 22.04": "ubuntu2204",
     "UnionTech OS Server 20": "uos20",
+    "OpenEmbedded": "openembedded",
     "Not Applicable" : "example"
 }
 
@@ -240,6 +245,9 @@ REFERENCES = dict(
     anssi=Reference(
         id="anssi", name="ANSSI", url=anssi_ns,
         regex_with_groups=r"BP28\(R(\d+)\)"),
+    ccn=Reference(
+        id="ccn", name="CCN", url="",
+        regex_with_groups=r"A\.(\d+)\.SEC-(\w+)(\d+)"),
     cis=Reference(
         id="cis", name="CIS", url=cis_ns,
         regex_with_groups=r"(\d+)\.(\d+)(?:\.(\w+)(?:\.(\w+)(?:\.(\w+))?)?)?"),
@@ -267,12 +275,12 @@ REFERENCES = dict(
 
 MULTI_PLATFORM_LIST = ["rhel", "fedora", "rhv", "debian", "ubuntu",
                        "opensuse", "sle", "ol", "ocp", "rhcos",
-                       "example", "eks", "alinux", "uos", "anolis"]
+                       "example", "eks", "alinux", "uos", "anolis", "openembedded"]
 
 MULTI_PLATFORM_MAPPING = {
     "multi_platform_alinux": ["alinux2", "alinux3"],
-    "multi_platform_anolis": ["anolis8"],
-    "multi_platform_debian": ["debian10", "debian11"],
+    "multi_platform_anolis": ["anolis8", "anolis23"],
+    "multi_platform_debian": ["debian10", "debian11", "debian12"],
     "multi_platform_example": ["example"],
     "multi_platform_eks": ["eks"],
     "multi_platform_fedora": ["fedora"],
@@ -285,6 +293,7 @@ MULTI_PLATFORM_MAPPING = {
     "multi_platform_sle": ["sle12", "sle15"],
     "multi_platform_ubuntu": ["ubuntu1604", "ubuntu1804", "ubuntu2004", "ubuntu2204"],
     "multi_platform_uos": ["uos20"],
+    "multi_platform_openembedded": ["openembedded"],
 }
 
 RHEL_CENTOS_CPE_MAPPING = {
@@ -454,18 +463,13 @@ MAKEFILE_ID_TO_PRODUCT_MAP = {
     'ocp': 'Red Hat OpenShift Container Platform',
     'rhcos': 'Red Hat Enterprise Linux CoreOS',
     'eks': 'Amazon Elastic Kubernetes Service',
+    'openembedded': 'OpenEmbedded',
 }
 
 # References that can not be used with product-qualifiers
 GLOBAL_REFERENCES = ("srg", "disa", "cis-csc",)
 
 # Application constants
-DEFAULT_GID_MIN = 1000
-DEFAULT_UID_MIN = 1000
-DEFAULT_NOBODY_GID = 65534
-DEFAULT_NOBODY_UID = 65534
-DEFAULT_GRUB2_BOOT_PATH = '/boot/grub2'
-DEFAULT_GRUB2_UEFI_BOOT_PATH = '/boot/grub2'
 DEFAULT_DCONF_GDM_DIR = 'gdm.d'
 DEFAULT_AIDE_CONF_PATH = '/etc/aide.conf'
 DEFAULT_AIDE_BIN_PATH = '/usr/sbin/aide'
@@ -475,3 +479,44 @@ DEFAULT_PRODUCT = 'example'
 DEFAULT_CHRONY_CONF_PATH = '/etc/chrony.conf'
 DEFAULT_AUDISP_CONF_PATH = '/etc/audit'
 DEFAULT_SYSCTL_REMEDIATE_DROP_IN_FILE = 'false'
+
+
+# Constants for OVAL object model
+STR_TO_BOOL = {
+    "false": False,
+    "False": False,
+    "true": True,
+    "True": True,
+}
+
+BOOL_TO_STR = {True: "true", False: "false"}
+
+
+class OvalNamespaces:
+    oval = "http://oval.mitre.org/XMLSchema/oval-common-5"
+    definition = oval_namespace
+    independent = "http://oval.mitre.org/XMLSchema/oval-definitions-5#independent"
+    linux = "http://oval.mitre.org/XMLSchema/oval-definitions-5#linux"
+
+
+OVAL_NAMESPACES = OvalNamespaces()
+
+DERIVATIVES_PRODUCT_MAPPING = {
+    "centos7": "rhel7",
+    "centos8": "rhel8",
+    "cs9": "rhel9",
+    "sl7": "rhel7"
+}
+
+BENCHMARKS = {
+    "apple_os",
+    "applications",
+    "linux_os/guide",
+    "products/chromium/guide",
+    "products/firefox/guide",
+}
+
+
+SSG_IDENT_URIS = {
+    'cce': cce_uri
+}
