@@ -264,7 +264,7 @@ def _make_file_root_owned(tarinfo):
     return tarinfo
 
 
-def get_product_context(product=None):
+def get_product_context(product_id=None):
     """
     Returns a product YAML context if any product is specified. Hard-coded to
     assume a debug build.
@@ -272,9 +272,11 @@ def get_product_context(product=None):
     # Load product's YAML file if present. This will allow us to parse
     # tests in the context of the product we're executing under.
     product_yaml = dict()
-    if product:
-        yaml_path = product_yaml_path(SSG_ROOT, product)
-        product_yaml.update(load_product_yaml(yaml_path))
+    if product_id:
+        product = load_product_yaml(product_yaml_path(SSG_ROOT, product_id))
+        product_properties_path = os.path.join(SSG_ROOT, "product_properties")
+        product.read_properties_from_directory(product_properties_path)
+        product_yaml.update(product)
 
     # We could run into a DocumentationNotComplete error when loading a
     # rule's YAML contents. However, because the test suite isn't executed
@@ -578,6 +580,7 @@ INSTALL_COMMANDS = dict(
     rhel7=("yum", "install", "-y"),
     rhel8=("yum", "install", "-y"),
     rhel9=("yum", "install", "-y"),
+    sles=("zypper", "install", "-y"),
     ubuntu=("DEBIAN_FRONTEND=noninteractive", "apt", "install", "-y"),
 )
 
@@ -599,24 +602,38 @@ def install_packages(test_env, packages):
             "Couldn't install required packages: {packages}".format(packages=",".join(packages)))
 
 
-def cpes_to_platform(cpes):
-    rhel_cpe = {"redhat:enterprise_linux": r":enterprise_linux:([^:]+):", "centos:centos": r"centos:centos:([0-9]+)"}
-    for cpe in cpes:
-        if "fedora" in cpe:
-            return "fedora"
-        for cpe_item in rhel_cpe.keys():
-            if cpe_item in cpe:
-                match = re.search(rhel_cpe.get(cpe_item), cpe)
-                if match:
-                    major_version = match.groups()[0].split(".")[0]
-                    return "rhel" + major_version
-        if "ubuntu" in cpe:
-            return "ubuntu"
-        if "oracle:linux" in cpe:
-            match = re.search(r":linux:([^:]+):", cpe)
+def _match_rhel_version(cpe):
+    rhel_cpe = {
+        "redhat:enterprise_linux": r":enterprise_linux:([^:]+):",
+        "centos:centos": r"centos:centos:([0-9]+)"}
+    for cpe_item in rhel_cpe.keys():
+        if cpe_item in cpe:
+            match = re.search(rhel_cpe.get(cpe_item), cpe)
             if match:
-                major_version = match.groups()[0]
-                return "ol" + major_version
+                major_version = match.groups()[0].split(".")[0]
+                return "rhel" + major_version
+
+
+def cpe_to_platform(cpe):
+    trivials = ["fedora", "sles", "ubuntu"]
+    for platform in trivials:
+        if platform in cpe:
+            return platform
+    rhel_version = _match_rhel_version(cpe)
+    if rhel_version is not None:
+        return rhel_version
+    if "oracle:linux" in cpe:
+        match = re.search(r":linux:([^:]+):", cpe)
+        if match:
+            major_version = match.groups()[0]
+            return "ol" + major_version
+
+
+def cpes_to_platform(cpes):
+    for cpe in cpes:
+        platform = cpe_to_platform(cpe)
+        if platform is not None:
+            return platform
     msg = "Unable to deduce a platform from these CPEs: {cpes}".format(cpes=cpes)
     raise ValueError(msg)
 
