@@ -34,7 +34,7 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
 def get_viable_profiles(selected_profiles, datastream, benchmark, script=None):
-    """Read datastream, and return set intersection of profiles of given
+    """Read data stream, and return set intersection of profiles of given
     benchmark and those provided in `selected_profiles` parameter.
     """
 
@@ -54,10 +54,10 @@ def get_viable_profiles(selected_profiles, datastream, benchmark, script=None):
 
     if not valid_profiles:
         if script:
-            logging.warning('Script {0} - profile {1} not found in datastream'
+            logging.warning('Script {0} - profile {1} not found in data stream'
                             .format(script, ", ".join(selected_profiles)))
         else:
-            logging.warning('Profile {0} not found in datastream'
+            logging.warning('Profile {0} not found in data stream'
                             .format(", ".join(selected_profiles)))
     return valid_profiles
 
@@ -280,7 +280,7 @@ class RuleChecker(oscap.Checker):
             List of named tuples Rule having these fields:
                 directory -- absolute path to the rule "tests" subdirectory
                             containing the test scenarios in Bash
-                id -- full rule id as it is present in datastream
+                id -- full rule id as it is present in data stream
                 short_id -- short rule ID, the same as basename of the directory
                             containing the test scenarios in Bash
                 template -- name of the template the rule uses
@@ -309,10 +309,10 @@ class RuleChecker(oscap.Checker):
             if not self._rule_matches_rule_spec(short_rule_id):
                 continue
             if full_rule_id not in all_rules_in_benchmark:
-                # This is an error only if the user specified the rules to be
+                # This is a problem only if the user specified the rules to be
                 # tested explicitly using command line arguments
                 if self.target_type == "rule ID":
-                    logging.error(
+                    logging.warning(
                         "Rule '{0}' isn't present in benchmark '{1}' in '{2}'"
                         .format(
                             full_rule_id, self.benchmark_id, self.datastream))
@@ -538,6 +538,9 @@ class RuleChecker(oscap.Checker):
                     "Rule {0} isn't part of profile {1} requested by "
                     "script {2}.".format(rule_id, profile_id, script)
                 )
+                return False
+        return True
+
 
     def _check_rule_scenario(self, scenario, remote_rule_dir, rule_id, remediation_available):
         if not _apply_script(
@@ -554,17 +557,12 @@ class RuleChecker(oscap.Checker):
         logging.debug('Using test script {0} with context {1}'
                       .format(scenario.script, scenario.context))
 
-        if scenario.script_params['profiles']:
-            profiles = get_viable_profiles(
-                scenario.script_params['profiles'], self.datastream, self.benchmark_id, scenario.script)
-            self._verify_rule_presence(rule_id, scenario.script, profiles)
-        else:
-            # Special case for combined mode when scenario.script_params['profiles']
-            # is empty which means scenario is not applicable on given profile.
-            logging.warning('Script {0} is not applicable on given profile'
-                            .format(scenario.script))
+        profiles = get_viable_profiles(
+            scenario.script_params['profiles'],
+            self.datastream, self.benchmark_id, scenario.script)
+        logging.debug("viable profiles are {0}".format(profiles))
+        if not self._verify_rule_presence(rule_id, scenario.script, profiles):
             return
-
         test_data = dict(scenario=scenario,
                          rule_id=rule_id,
                          remediation_available=remediation_available)
