@@ -2,6 +2,7 @@ import contextlib
 import collections
 import os
 import tempfile
+import sys
 
 import yaml
 import pytest
@@ -195,10 +196,10 @@ def test_make_items_product_specific():
     assert rule.template["backends"]["anaconda"]
 
     rule.references = {
-        "stigid@rhel7": "RHEL-07-040370,RHEL-07-057364",
+        "stigid@rhel8": "RHEL-08-020012,RHEL-08-020013",
     }
-    with pytest.raises(ValueError, match="Rules can not have multiple STIG IDs."):
-        rule.make_refs_and_identifiers_product_specific("rhel7")
+    rule.normalize("rhel8")
+    assert rule.references["stigid"] == "RHEL-08-020012,RHEL-08-020013"
 
 
 def test_priority_ordering():
@@ -437,6 +438,7 @@ def rule_accounts_tmout():
     return ssg.build_yaml.Rule.from_yaml(rule_file)
 
 
+@pytest.mark.skipif(sys.version_info[0] < 3, reason="requires python3 or higher")
 def test_rule_to_xml_element(rule_accounts_tmout):
     xmldiff_main = pytest.importorskip("xmldiff.main")
     rule_el = rule_accounts_tmout.to_xml_element()
@@ -469,6 +471,7 @@ def value_system_crypto_policy():
     return ssg.build_yaml.Value.from_yaml(value_file)
 
 
+@pytest.mark.skipif(sys.version_info[0] < 3, reason="requires python3 or higher")
 def test_value_to_xml_element(value_system_crypto_policy):
     xmldiff_main = pytest.importorskip("xmldiff.main")
     value_el = value_system_crypto_policy.to_xml_element()
@@ -533,3 +536,25 @@ def test_rule_to_ocil(rule_accounts_tmout):
             expected_file_path = os.path.join(DATADIR, expected_filename)
             diff = xmldiff_main.diff_files(real_file_path, expected_file_path)
             assert diff == []
+
+
+@pytest.fixture()
+def profile_without_version(profile_ospp):
+    profile_ospp.metadata.pop('version', None)
+    return profile_ospp
+
+
+def test_profile_without_version(profile_without_version):
+    profile_el = profile_without_version.to_xml_element()
+    assert profile_el.find("{%s}version" % XCCDF12_NS) is None
+
+
+@pytest.fixture()
+def profile_with_version(profile_ospp):
+    profile_ospp.metadata["version"] = "3.2.1"
+    return profile_ospp
+
+
+def test_profile_with_version(profile_with_version):
+    profile_el = profile_with_version.to_xml_element()
+    assert profile_el.find("{%s}version" % XCCDF12_NS).text == "3.2.1"
