@@ -1,6 +1,7 @@
 import pytest
 import logging
 import os
+import sys
 
 import ssg.controls
 import ssg.build_yaml
@@ -13,12 +14,7 @@ controls_dir = os.path.join(data_dir, "controls_dir")
 profiles_dir = os.path.join(data_dir, "profiles_dir")
 
 
-def _load_test(profile):
-    product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
-    build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
-    env_yaml = open_environment(build_config_yaml, product_yaml)
-    controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-    controls_manager.load()
+def assert_control_confirms_to_standard(controls_manager, profile):
     c_r1 = controls_manager.get_control(profile, "R1")
     assert c_r1.title == "User session timeout"
     assert c_r1.description == "Remote user sessions must be closed after " \
@@ -46,6 +42,8 @@ def _load_test(profile):
     assert "accounts_password_pam_ocredit" in c_r4_rules
     assert "var_password_pam_ocredit" in c_r4.variables
     assert c_r4.variables["var_password_pam_ocredit"] == "1"
+    assert "R4.a" in c_r4.controls
+    assert "R4.b" in c_r4.controls
     c_r5 = controls_manager.get_control(profile, "R5")
     assert c_r5.id == "R5"
     assert c_r5.status == "does not meet"
@@ -60,17 +58,60 @@ def _load_test(profile):
     assert c_r5.status_justification == "Mitigate with third-party software."
 
 
-def test_controls_load():
-    _load_test("abcd")
-
-
-def test_controls_levels():
+@pytest.fixture
+def env_yaml():
     product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
     build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
     env_yaml = open_environment(build_config_yaml, product_yaml)
+    return env_yaml
+
+
+@pytest.fixture
+def controls_manager(env_yaml):
     controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
     controls_manager.load()
+    return controls_manager
 
+
+@pytest.fixture
+def compiled_controls_dir_py2(tmpdir):
+    return str(tmpdir)
+
+
+@pytest.fixture
+def compiled_controls_dir_py3(tmp_path):
+    return tmp_path
+
+
+@pytest.fixture
+def compiled_controls_manager(env_yaml, controls_manager,compiled_controls_dir_py2):
+    controls_manager.save_everything(compiled_controls_dir_py2)
+    controls_manager = ssg.controls.ControlsManager(compiled_controls_dir_py2, env_yaml)
+    controls_manager.load()
+    return controls_manager
+
+
+def _load_test(controls_manager, profile):
+    assert_control_confirms_to_standard(controls_manager, profile)
+
+
+def test_controls_load(controls_manager):
+    _load_test(controls_manager, "abcd")
+
+
+@pytest.mark.skipif(sys.version_info[0] < 3, reason="requires python3 or higher")
+def test_controls_invalid_rules(env_yaml):
+    existing_rules = {"accounts_tmout", "configure_crypto_policy"}
+    controls_manager = ssg.controls.ControlsManager(
+        controls_dir, env_yaml, existing_rules)
+    with pytest.raises(ValueError) as exc:
+        controls_manager.load()
+    assert str(exc.value) == \
+        "Control abcd:R1 contains nonexisting rule(s) sshd_set_idle_timeout"
+
+
+@pytest.mark.skipif(sys.version_info[0] < 3, reason="requires python3 or higher")
+def test_controls_levels(controls_manager):
     # Default level is the lowest level
     c_1 = controls_manager.get_control("abcd-levels", "S1")
     assert c_1.levels == ["low"]
@@ -185,14 +226,7 @@ def test_controls_levels():
     assert "configure_crypto_policy" in s7_high[0].selections
 
 
-def test_controls_load_product():
-    product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
-    build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
-    env_yaml = open_environment(build_config_yaml, product_yaml)
-
-    controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-    controls_manager.load()
-
+def test_controls_load_product(controls_manager):
     c_r1 = controls_manager.get_control("abcd", "R1")
     assert c_r1.title == "User session timeout"
     assert c_r1.description == "Remote user sessions must be closed after " \
@@ -207,20 +241,21 @@ def test_controls_load_product():
     assert c_r1.variables["var_accounts_tmout"] == "10_min"
 
 
-def test_profile_resolution_inline():
+def test_profile_resolution_inline(env_yaml, controls_manager):
     profile_resolution(
-        ssg.build_yaml.ProfileWithInlinePolicies, "abcd-low-inline")
+        env_yaml, controls_manager, ssg.build_yaml.ProfileWithInlinePolicies, "abcd-low-inline")
 
 
-def test_profile_resolution_extends_inline():
+def test_profile_resolution_extends_inline(env_yaml, controls_manager):
     profile_resolution_extends(
+        env_yaml, controls_manager,
         ssg.build_yaml.ProfileWithInlinePolicies,
         "abcd-low-inline", "abcd-high-inline")
 
 
-def test_profile_resolution_all_inline():
+def test_profile_resolution_all_inline(env_yaml, controls_manager):
     profile_resolution_all(
-        ssg.build_yaml.ProfileWithInlinePolicies, "abcd-all-inline")
+        env_yaml, controls_manager, ssg.build_yaml.ProfileWithInlinePolicies, "abcd-all-inline")
 
 
 class DictContainingAnyRule(dict):
@@ -233,13 +268,7 @@ class DictContainingAnyRule(dict):
         return True
 
 
-def profile_resolution(cls, profile_low):
-    product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
-    build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
-    env_yaml = open_environment(build_config_yaml, product_yaml)
-
-    controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-    controls_manager.load()
+def profile_resolution(env_yaml, controls_manager, cls, profile_low):
     low_profile_path = os.path.join(profiles_dir, profile_low + ".profile")
     profile = cls.from_yaml(low_profile_path, env_yaml)
     all_profiles = {"abcd-low": profile}
@@ -261,15 +290,7 @@ def profile_resolution(cls, profile_low):
     assert "security_patches_up_to_date" in selected
 
 
-def profile_resolution_extends(cls, profile_low, profile_high):
-    product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
-    build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
-    env_yaml = open_environment(build_config_yaml, product_yaml)
-
-    # tests ABCD High profile which is defined as an extension of ABCD Low
-    controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-    controls_manager.load()
-
+def profile_resolution_extends(env_yaml, controls_manager, cls, profile_low, profile_high):
     low_profile_path = os.path.join(profiles_dir, profile_low + ".profile")
     low_profile = cls.from_yaml(low_profile_path, env_yaml)
     high_profile_path = os.path.join(profiles_dir, profile_high + ".profile")
@@ -299,13 +320,7 @@ def profile_resolution_extends(cls, profile_low, profile_high):
     assert high_profile.variables["var_password_pam_ocredit"] == "2"
 
 
-def profile_resolution_all(cls, profile_all):
-    product_yaml = os.path.join(ssg_root, "products", "rhel8", "product.yml")
-    build_config_yaml = os.path.join(ssg_root, "build", "build_config.yml")
-    env_yaml = open_environment(build_config_yaml, product_yaml)
-
-    controls_manager = ssg.controls.ControlsManager(controls_dir, env_yaml)
-    controls_manager.load()
+def profile_resolution_all(env_yaml, controls_manager, cls, profile_all):
     profile_path = os.path.join(profiles_dir, profile_all + ".profile")
     profile = cls.from_yaml(profile_path, env_yaml)
     all_profiles = {profile_all: profile}
@@ -336,13 +351,165 @@ def profile_resolution_all(cls, profile_all):
     assert "security_patches_up_to_date" in selected
 
 
-def test_load_control_from_folder():
-    _load_test("qrst")
+def test_load_control_from_folder(controls_manager):
+    _load_test(controls_manager, "qrst")
 
 
-def test_load_control_from_folder_and_file():
-    _load_test("jklm")
+def test_load_control_from_folder_and_file(controls_manager):
+    _load_test(controls_manager, "jklm")
 
 
-def test_load_control_from_specific_folder_and_file():
-    _load_test("nopq")
+def test_load_compiled_control_from_folder_and_file(compiled_controls_dir_py2, compiled_controls_manager):
+    _load_test(compiled_controls_manager, "jklm")
+
+
+def test_load_control_from_specific_folder_and_file(controls_manager):
+    _load_test(controls_manager, "nopq")
+
+
+@pytest.fixture
+def minimal_empty_controls():
+    return [dict(title="control", id="c", rules=["a"])]
+
+
+@pytest.fixture
+def one_simple_subcontrol():
+    return dict(title="subcontrol", id="s", rules=["b"])
+
+
+def test_policy_parse_from_dict(minimal_empty_controls):
+    policy = ssg.controls.Policy("")
+    controls = policy.save_controls_tree(minimal_empty_controls)
+    controls = policy.controls
+    assert len(controls) == 1
+    control = controls[0]
+    assert control.title == "control"
+
+
+def test_policy_fail_parse_from_incomplete_dict(minimal_empty_controls):
+    incomplete_controls = minimal_empty_controls
+    incomplete_controls[0]["controls"] = [dict(title="nested")]
+
+    policy = ssg.controls.Policy("")
+
+    with pytest.raises(RuntimeError, match="id"):
+        policy.save_controls_tree(incomplete_controls)
+
+
+def order_by_attribute(items, attribute, ordering):
+    items_by_attribute = {getattr(i, attribute): i for i in items}
+    return [items_by_attribute[val] for val in ordering]
+
+
+def test_policy_parse_from_nested(minimal_empty_controls, one_simple_subcontrol):
+    nested_controls = minimal_empty_controls
+    nested_controls[0]["controls"] = [one_simple_subcontrol]
+
+    policy = ssg.controls.Policy("P")
+    controls = policy.save_controls_tree(minimal_empty_controls)
+    controls = policy.controls
+    assert len(controls) == 2
+    control, subcontrol = order_by_attribute(controls, "id", ("c", "s"))
+    assert control.title == "control"
+    assert control.selections == ["a"]
+    assert subcontrol.title == "subcontrol"
+    assert subcontrol.selections == ["b"]
+
+    controls_manager = ssg.controls.ControlsManager("", dict())
+    controls_manager.policies[policy.id] = policy
+
+    controls_manager.resolve_controls()
+    control = policy.get_control("c")
+    assert control.selections == ["a", "b"]
+
+
+def test_manager_removes_rules():
+    control_dict = dict(id="top", rules=["one", "two", "three", "!four", "!five"])
+
+    policy = ssg.controls.Policy("")
+    policy.save_controls_tree([control_dict])
+    policy.id = "P"
+
+    controls_manager = ssg.controls.ControlsManager("", dict())
+    controls_manager.policies[policy.id] = policy
+
+    control = controls_manager.get_control("P", "top")
+    assert len(control.selections) == 5
+
+    controls_manager.remove_selections_not_known(["one", "four"])
+    control = controls_manager.get_control("P", "top")
+    assert len(control.selections) == 2
+    assert "one" in control.selections
+    assert "!four" in control.selections
+
+    controls_manager.remove_selections_not_known([])
+    control = controls_manager.get_control("P", "top")
+    assert len(control.selections) == 0
+
+
+def test_policy_parse_from_nested():
+    top_control_dict = dict(id="top", controls=["nested-1"])
+    first_nested_dict = dict(id="nested-1", controls=["nested-2"], rules="Y")
+    second_nested_dict = dict(id="nested-2", rules=["X"])
+
+    policy = ssg.controls.Policy("")
+    policy.id = "P"
+
+    controls_manager = ssg.controls.ControlsManager("", dict())
+    controls_manager.policies[policy.id] = policy
+
+    controls = policy.save_controls_tree([top_control_dict, second_nested_dict, first_nested_dict])
+    controls_manager.resolve_controls()
+    control = policy.get_control("top")
+    assert "Y" in control.selections
+    assert "X" in control.selections
+
+
+def test_policy_parse_from_ours_and_foreign():
+    main_control_dict = dict(id="top", controls=["foreign:top", "ours", "P:ours_qualified"])
+    main_subcontrol_dicts = [dict(id="ours", rules=["ours"]), dict(id="ours_qualified", rules=["really_ours"])]
+    foreign_control_dict = dict(id="top", rules=["foreign"])
+
+    main_policy = ssg.controls.Policy("")
+    main_policy.id = "P"
+    main_policy.save_controls_tree([main_control_dict] + main_subcontrol_dicts)
+
+    foreign_policy = ssg.controls.Policy("")
+    foreign_policy.id = "foreign"
+    foreign_policy.save_controls_tree([foreign_control_dict])
+
+    controls_manager = ssg.controls.ControlsManager("", dict())
+    controls_manager.policies[main_policy.id] = main_policy
+    controls_manager.policies[foreign_policy.id] = foreign_policy
+
+    controls_manager.resolve_controls()
+    control = controls_manager.get_control("P", "top")
+    assert "ours" in control.selections
+    assert "really_ours" in control.selections
+    assert "foreign" in control.selections
+
+
+def test_policy_parse_from_referenced(minimal_empty_controls, one_simple_subcontrol):
+    nested_controls = minimal_empty_controls
+    nested_controls[0]["controls"] = ["s"]
+    nested_controls.append(one_simple_subcontrol)
+
+    policy = ssg.controls.Policy("")
+    policy.id = "P"
+    controls = policy.save_controls_tree(minimal_empty_controls)
+    controls = policy.controls
+    assert len(controls) == 2
+    control, subcontrol = order_by_attribute(controls, "id", ("c", "s"))
+    assert control.title == "control"
+    assert control.controls == ["s"]
+    assert subcontrol.title == "subcontrol"
+
+
+def test_control_with_bad_key():
+    control = {'id': 'abcd', 'badval': 'should not be here', }
+    control_obj = None
+    try:
+        control_obj = ssg.controls.Control.from_control_dict(control)
+    except ValueError as e:
+        assert type(e) is ValueError
+    assert control_obj is None
